<?php

use Illuminate\Database\Migrations\Migration;
use Illuminate\Database\Schema\Blueprint;
use Illuminate\Support\Facades\Schema;

return new class extends Migration
{
    /**
     * Run the migrations.
     */
    public function up(): void
    {
        Schema::create('chatbot_conversations', function (Blueprint $table) {
            $table->smallIncrements('id');

            $table->uuid('uuid')->unique()->index();

            // Relaciones polimórficas para participantes (usuarios, clientes, visitantes anónimos)
            $table->unsignedMediumInteger('user_id')->nullable()->index();

            $table->unsignedSmallInteger('provider_id')->index();

            $table->enum('status', ['active', 'closed', 'archived'])->default('active')->index();

            // Auditoría
            $table->timestamps();
            $table->softDeletes();

            // Relaciones
            $table->foreign('user_id')->references('id')->on('users')->nullOnDelete();
            $table->foreign('provider_id')->references('id')->on('chatbot_providers')->cascadeOnUpdate()->cascadeOnDelete();
        });
    }

    /**
     * Reverse the migrations.
     */
    public function down(): void
    {
        Schema::dropIfExists('chatbot_conversations');
    }
};
